///
/// \file    ArgoneutOrtho3dView.h
/// \brief   A view showing an orthographic projection of 3D objects based on Ortho3DView.
/// \author  tjyang@fnal.gov
///
/// Only 3D objects (prongs and space points) can be displayed in this view.
///

#ifndef EVD_ARGONEUTORTHO3DVIEW_H
#define EVD_ARGONEUTORTHO3DVIEW_H
#include <vector>

#include "nuevdb/EventDisplayBase/Canvas.h"

namespace argoevd {

  class ArgoneutOrtho3DPad;

  /// View of event shoing orthographic view of 3D objects.

  class ArgoneutOrtho3DView : public evdb::Canvas {

  public:

    // Constructor, destructor.

    ArgoneutOrtho3DView(TGMainFrame* mf);
    virtual ~ArgoneutOrtho3DView();

    // Required methods.
    
    const char* Description() const { return "ArgoNeuT Orthographic 3D Detector Display"; }
    const char* PrintTag()    const { return "argoortho3d";               }
    void Draw(const char* opt="");

  private:

    // Attributes.

    // Graphics pads.

    std::vector<ArgoneutOrtho3DPad*> fArgoneutOrtho3DPads; ///< Graphics pads.

    // Frames.

    TGCompositeFrame* fMetaFrame;    ///< Frame holding root canvas and widget frame.
    TGCompositeFrame* fWidgetFrame;  ///< Frame holding widgets.
    std::vector<TGCompositeFrame*> fWidgetSubFrames; // Frame holding widgets for one pad.
  };
}

#endif
////////////////////////////////////////////////////////////////////////
